@@ -6,6 +6,8 @@
 
 #include <QWebEngineUrlRequestInterceptor>
 
+#include <angelfishsettings.h>
+
 #ifdef BUILD_ADBLOCK
 #include <adblock.rs.h>
 #include <optional>
@@ -53,6 +55,7 @@ public:
     Q_INVOKABLE std::vector<QString> getCosmeticFilters(const QUrl &url,
                                                         const std::vector<QString> &classes,
                                                         const std::vector<QString> &ids) const;
+    Q_INVOKABLE QString getInjectedScript(const QUrl &url) const;
 #endif
 
     Q_SIGNAL void adblockInitialized();
